PymoNNto

The "Python Modular Neural Network Toolbox" allows you to create neuron groups, define their behaviour and connect them with synapse groups.

https://github.com/trieschlab/PymoNNto

https://pymonnto.readthedocs.io